package com.aspose.cells.demos.chart;

import javax.servlet.http.HttpServletRequest;

import com.aspose.cells.Axis;
import com.aspose.cells.Cells;
import com.aspose.cells.Chart;
import com.aspose.cells.ChartCollection;
import com.aspose.cells.ChartType;
import com.aspose.cells.Color;
import com.aspose.cells.FileFormatType;
import com.aspose.cells.Font;
import com.aspose.cells.LegendPositionType;
import com.aspose.cells.SeriesCollection;
import com.aspose.cells.Title;
import com.aspose.cells.Workbook;
import com.aspose.cells.Worksheet;
import com.aspose.cells.WorksheetCollection;
import com.aspose.cells.demos.DemoBaseServlet;

public class ClusteredBarServlet extends DemoBaseServlet
{
    private static final String TEMPLATE_FILE_PATH_PART = "/WEB-INF/Designer/Chart/BarTemplate.xls";

    protected Workbook createReport(HttpServletRequest request) throws Exception
    {
        int fileFormatType = FileFormatType.EXCEL_97_TO_2003;
        resultFile = "ClusteredBar.xls";

        Workbook wb = new Workbook(getServletContext().getRealPath(TEMPLATE_FILE_PATH_PART));
        createStaticReport(wb, request.getParameter("CheckBoxShow3D") != null
                ? ChartType.BAR_3_D_CLUSTERED : ChartType.BAR);
        return wb;
    }

    private void createStaticReport(Workbook workbook, int type) throws Exception
    {
        WorksheetCollection worksheets = workbook.getWorksheets();
        Worksheet worksheet = worksheets.get(0);
        //Set the name of worksheet
        worksheet.setName("Clustered Bar");

        //Create chart
        ChartCollection charts = worksheet.getCharts();
        Chart chart = charts.get(charts.add(type, 5, 1, 26, 10));

        //Set properties of chart title
        Title title = chart.getTitle();
        title.setText("Fruit Sales By Region");
        Font font1 = title.getTextFont();
        font1.setColor(Color.getBlack());
        font1.setBold(true);
        font1.setSize(12);

        //Set properties of nseries
        SeriesCollection nSeries = chart.getNSeries();
        nSeries.add("B2:C4", true);
        nSeries.setCategoryData("A2:A4");

        Cells cells = worksheet.getCells();
        String temp;
        for(int i = 0; i < nSeries.getCount(); i++)
        {
            temp = cells.get(0, i + 1).getStringValue();
            nSeries.get(i).setName(temp);
            nSeries.get(i).setColorVaried(true);
        }

        //Set properties of categoryaxis title
        Axis categoryAxis = chart.getCategoryAxis();
        title = categoryAxis.getTitle();
        title.setText("Region");
        Font font2 = title.getTextFont();
        font2.setBold(true);
        font2.setColor(Color.getBlack());
        font2.setSize(10);
        title.setRotationAngle(90);

        //Set properties of legend
        chart.getLegend().setPosition(LegendPositionType.TOP);
    }
}
